yakumo.nova.v2.aggregate.Resource

Package yakumo :: Package nova :: Package v2 :: Module aggregate :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for aggregates in Compute API v2

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`) Update properties of a host aggregate | source code
None |
add_hosts(self, *hosts) Register hosts to a host aggregate | source code
None |
remove_hosts(self, *hosts) Unregister hosts from a host aggregate | source code
dict |
get_metadata(self) Aquire metadata of a host aggregate | source code
None |
set_metadata(self, **metadata) Set metadata for a host aggregate | source code
None |
unset_metadata(self, *keys) Remove metadata of a host aggregate | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`) | source code
Update properties of a host aggregate Parameters: `name` (str) - Name of the host aggregate `availability_zone` (str) - Name of availability zone Returns: None Overrides: base.Resource.update

### add_hosts(self, *hosts) | source code
Register hosts to a host aggregate Parameters: `hosts` ([str]) Returns: None

### remove_hosts(self, *hosts) | source code
Unregister hosts from a host aggregate Parameters: `hosts` ([str]) - List of host names Returns: None

### get_metadata(self) | source code
Aquire metadata of a host aggregate Returns: dict Metadata

### set_metadata(self, **metadata) | source code
Set metadata for a host aggregate Parameters: `metadata` (dict) - Metadata as key=value Returns: None

### unset_metadata(self, *keys) | source code
Remove metadata of a host aggregate Parameters: `keys` ([str]) - metadata keys to remove Returns: None